@@ -1,8 +1,8 @@
 
 /*
- *  Time-stamp:      "2003-04-28 18:41:25 bkorb"
+ *  Time-stamp:      "2003-05-26 08:04:30 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.36 2003/04/29 01:42:37 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 2.38 2003/05/31 22:59:15 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
@@ -130,29 +130,14 @@ typedef struct {
     char*      pzOptArg;
 } tOptState;
 
-#if defined( __STDC__ ) || defined( __cplusplus )
-#  ifndef PROTO
-#    define PROTO(s) s
-#  endif
-
-#else
-#  ifndef PROTO
-#    define PROTO(s) ()
-#  endif
-
-#endif
-
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *  MEMORY DEBUGGING
- */
-
 #  define AGALOC( c, w )        malloc( c )
 #  define AGREALOC( p, c, w )   realloc( p, c )
-#  define AGDUPSTR( p, s, w )   strdup( p )
 #  define AGFREE( p )           free( p )
+#  define AGDUPSTR( p, s, w )   p = strdup( s )
 #  define TAGMEM( m, t )
 
+#ifdef AUTOGEN_BUILD
+#  include <snprintfv/printf.h>
 
 /*
  *  File pointer for usage output
@@ -163,13 +148,13 @@ extern FILE* option_usage_fp;
  *  optionUsage print the usage text for the program described by the
  *  option descriptor.  Does not return.  Calls ``exit(3)'' with exitCode.
  */
-extern void optionUsage PROTO(( tOptions*, int exitCode ));
+extern void optionUsage( tOptions*, int exitCode );
 
 /*
  *  optionSave saves the option state into an RC or INI file in
  *  the *LAST* defined directory in the papzHomeList.
  */
-void    optionSave PROTO((   tOptions* pOpts ));
+extern void optionSave( tOptions* pOpts );
 
 /*
  *  optionMakePath  --  translate and construct a path
@@ -178,11 +163,11 @@ void    optionSave PROTO((   tOptions* pOpts ));
  *  is a ``$''.  If it starts with two dollar characters, then the path
  *  is relative to the location of the executable.
  */
-ag_bool optionMakePath PROTO((
+extern ag_bool optionMakePath(
     char*    pzBuf,
     size_t   bufSize,
     tCC*     pzName,
-    tCC*     pzProgPath ));
+    tCC*     pzProgPath );
 
 extern tOptProc doVersion, doPagedUsage, doLoadOpt;
 
